@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Union
 
 from fastapi import FastAPI
 from pydantic import BaseModel, EmailStr
@@ -10,7 +10,7 @@ class UserIn(BaseModel):
     username: str
     password: str
     email: EmailStr
-    full_name: Optional[str] = None
+    full_name: Union[str, None] = None
 
 
 # Don't do this in production!
