@@ -43,6 +43,7 @@ from pydantic.fields import (
     FieldInfo,
     ModelField,
     Required,
+    Undefined,
 )
 from pydantic.schema import get_annotation_from_field_info
 from pydantic.typing import ForwardRef, evaluate_forwardref
@@ -160,7 +161,6 @@ def get_sub_dependant(
     )
     if security_requirement:
         sub_dependant.security_requirements.append(security_requirement)
-    sub_dependant.security_scopes = security_scopes
     return sub_dependant
 
 
@@ -277,7 +277,13 @@ def get_dependant(
     path_param_names = get_path_param_names(path)
     endpoint_signature = get_typed_signature(call)
     signature_params = endpoint_signature.parameters
-    dependant = Dependant(call=call, name=name, path=path, use_cache=use_cache)
+    dependant = Dependant(
+        call=call,
+        name=name,
+        path=path,
+        security_scopes=security_scopes,
+        use_cache=use_cache,
+    )
     for param_name, param in signature_params.items():
         if isinstance(param.default, params.Depends):
             sub_dependant = get_param_sub_dependant(
@@ -316,7 +322,7 @@ def get_dependant(
             field_info = param_field.field_info
             assert isinstance(
                 field_info, params.Body
-            ), f"Param: {param_field.name} can only be a request body, using Body(...)"
+            ), f"Param: {param_field.name} can only be a request body, using Body()"
             dependant.body_params.append(param_field)
     return dependant
 
@@ -353,7 +359,7 @@ def get_param_field(
     force_type: Optional[params.ParamTypes] = None,
     ignore_default: bool = False,
 ) -> ModelField:
-    default_value = Required
+    default_value: Any = Undefined
     had_schema = False
     if not param.default == param.empty and ignore_default is False:
         default_value = param.default
@@ -369,8 +375,13 @@ def get_param_field(
         if force_type:
             field_info.in_ = force_type  # type: ignore
     else:
-        field_info = default_field_info(default_value)
-    required = default_value == Required
+        field_info = default_field_info(default=default_value)
+    required = True
+    if default_value is Required or ignore_default:
+        required = True
+        default_value = None
+    elif default_value is not Undefined:
+        required = False
     annotation: Any = Any
     if not param.annotation == param.empty:
         annotation = param.annotation
@@ -382,12 +393,11 @@ def get_param_field(
     field = create_response_field(
         name=param.name,
         type_=annotation,
-        default=None if required else default_value,
+        default=default_value,
         alias=alias,
         required=required,
         field_info=field_info,
     )
-    field.required = required
     if not had_schema and not is_scalar_field(field=field):
         field.field_info = params.Body(field_info.default)
     if not had_schema and lenient_issubclass(field.type_, UploadFile):
@@ -490,7 +500,6 @@ async def solve_dependencies(
                 name=sub_dependant.name,
                 security_scopes=sub_dependant.security_scopes,
             )
-            use_sub_dependant.security_scopes = sub_dependant.security_scopes
 
         solved_result = await solve_dependencies(
             request=request,
